from _typeshed import Incomplete
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

PMI1: Incomplete
PMI2: Incomplete
PMI3: Incomplete
NPR1: Incomplete
NPR2: Incomplete
RadiusOfGyration: Incomplete
InertialShapeFactor: Incomplete
Eccentricity: Incomplete
Asphericity: Incomplete
SpherocityIndex: Incomplete
